import java.text.NumberFormat;
import java.util.Locale;

public class Euro {
	private final long cents;

	public Euro(double euro) {
		if (euro < 0)
			throw new IllegalArgumentException("negative amount");

		cents = Math.round(euro * 100.0);
	}

	private Euro(long cents) {
		this.cents = cents;
	}

	public Euro plus(Euro other) {
		return new Euro(this.cents + other.cents);
	}

	public Euro times(int factor) {
		return new Euro(cents * factor);
	}

	public double getAmount() {
		return cents / 100.0;
	}

	public String format() {
		NumberFormat format = NumberFormat.getInstance(Locale.GERMAN);
		format.setMinimumFractionDigits(2);
		return format.format(getAmount());
	}

	public String toString() {
		return "EUR " + getAmount();
	}

	public boolean equals(Object o) {
		if (o == null || !o.getClass().equals(this.getClass())) {
			return false;
		}

		Euro other = (Euro) o;
		return this.cents == other.cents;
	}

	public int hashCode() {
		return (int) cents;
	}
}